extern crate mpd;

mod noise;
use noise::{commands::Noise, parser::*};

use clap::{Command, CommandFactory, Parser};
use clap_complete::{generate, Generator};
use mpd::Client;
use std::io;

fn print_completions<G: Generator>(generator: G, cmd: &mut Command) {
    generate(
        generator,
        cmd,
        cmd.get_name().to_string(),
        &mut io::stdout(),
    );
}

fn main() {
    let cli = Cli::parse();

    if let Some(completions) = cli.completions {
        let mut cmd = Cli::command();
        eprintln!("Generatig completion file for {completions:?}...");
        print_completions(completions, &mut cmd);
        return;
    }

    let host = cli.host.unwrap_or("localhost:6600".into());

    let mut conn = Client::connect(host).expect("Connection failed");

    if let Some(cmd) = &cli.command {
        match cmd {
            Commands::Play { track } => conn.noise_play(*track),
            Commands::Stop => conn.stop().unwrap(),
            Commands::Toggle => conn.toggle(),
            Commands::Next => conn.next().unwrap(),
            Commands::Prev => conn.prev().unwrap(),
            Commands::List { file } => conn.list_queue(*file, cli.verbose),
            Commands::Current => (),
            Commands::Clear => conn.clear().unwrap(),
            Commands::Search { query, max } => conn.noise_search(query, *max),
            Commands::Find { query, max, append } => conn.noise_find(query, *max, *append),
            Commands::Crossfade { seconds } => conn.noise_crossfade(*seconds),
            Commands::Shuffle => conn.shuf(),
            Commands::Repeat => conn.toggle_repeat(),
            Commands::Random => conn.toggle_random(),
            Commands::Single => conn.toggle_single(),
            Commands::Consume => conn.toggle_consume(),
            Commands::Volume { percentage } => conn.vol(*percentage),
            Commands::Munch => conn.munch(),
            Commands::Length => conn.length(),
        }

        if let Commands::Stop
        | Commands::List { .. }
        | Commands::Clear
        | Commands::Search { .. }
        | Commands::Find { .. }
        | Commands::Crossfade { .. }
        | Commands::Shuffle = cmd
        {
            return;
        }
    }
    println!("{}", conn.get_status(cli.verbose));
}
